using UnityEngine;
using System.Collections;
using UnityEngine.SceneManagement;

/* 
	 * PlayerStats: Stores all numerical stats of player.  For player appearance, see setAppearance.cs
	 * - Any changes to health, ingame stats, currency, etc will use a getting and/or setter from here
	 * - This scripts should always be a component of "Player" (or the root object containing all player parts)
	 */
public class PlayerStats : MonoBehaviour {

	private static float maxHealth;
	public static float curHealth;
	private static string playerName;
	private static int vitality;
	private static int strength;
	private static int defense;
	private static int agility;
	private static int luck;
	private static int money;

	public WeaponStats defaultWeapon; // Incase currentWeapon not set properly.  Set this in inspector!
	private static WeaponStats currentWeapon;
	EnterDoor spawn;

	void Start() {
		Debug.Log ("Player Stats:\n\nname: "+playerName+"\nvit: "+vitality+"\nstr: "+strength+"\ndef: "+defense+"\nagi: "+agility+"\nluck: "+luck);
		updateWeapon();
	}

	IEnumerator waitandload() {
		//leave time for a death animation and a defeat message, then load the main scene
		yield return new WaitForSeconds(2.0f);
		SceneManager.LoadScene("Town01");
	}

	public void ApplyDamageP(int damage) {
		curHealth -= damage;
		if (curHealth <= 0) {
			StartCoroutine("waitandload");
		}
	}

	public void ChangeHealthBarp(int damage) {
		GameObject healthbar = GameObject.Find("healthbarFullp");
		float newsize = healthbar.transform.localScale.x - ((damage / maxHealth) * 0.3f);
		healthbar.transform.localScale = new Vector3(newsize, 0.3f, 1f);
		if (curHealth <= 0) {
			healthbar.GetComponent<SpriteRenderer>().enabled = false;
		}
	}

	private void updateWeapon() {
		GameObject weapon = GameObject.FindWithTag("currentWeapon"); // Get player weapon from scene
		SpriteRenderer spriteRenderer = weapon.GetComponent<SpriteRenderer> ();
		if (currentWeapon != null) {
			spriteRenderer.sprite = currentWeapon.image; // Set correct image of current weapon
		}
		else {
			spriteRenderer.sprite = defaultWeapon.image; // Incase somethings wrong with currentWeapon
		}

	}

	public static float getHealth() {
		return curHealth;
	}

	public void setWeapon(WeaponStats newWeapon) {
		currentWeapon = newWeapon;
		updateWeapon();
	}

	public void setName(string newName) {
		playerName = newName;
	}

	public void setVitality(int newVitality) {
		vitality = newVitality;
		setMaxHealth(); // Vitality affects HP amount
	}

	// Calculated from vitality
	private void setMaxHealth() {
		maxHealth = vitality * 10;
		curHealth = maxHealth;
	}

	public void setStrength(int newStrength) {
		strength = newStrength;
	}

	public void setDefense(int newDefense) {
		defense = newDefense;
	}

	public void setAgility(int newAgility) {
		agility = newAgility;
	}

	public void setLuck(int newLuck) {
		luck = newLuck;
	}

	public void changeMoney(int incr){
		money += incr;
	}

	public int getMoney(){
		return money;
	}



}